@@ -1,6 +1,6 @@
 utils::globalVariables(c(
   "AEDECOD",
-  "AESER", 
+  "AESER",
   "AESEV",
   "AESTDT",
   "..prop..",
@@ -29,17 +29,17 @@ utils::globalVariables(c(
   "value",
   "ymax",
   "ymin",
-  "stats", 
-  "as.dist", 
-  "cor", 
+  "stats",
+  "as.dist",
+  "cor",
   "hclust",
   "PopuExplor",
-  "AVAL", 
-  "AVISIT", 
-  "AVISITN", 
-  "CMDECOD", 
-  "CMSTDT", 
-  "DECODE", 
+  "AVAL",
+  "AVISIT",
+  "AVISITN",
+  "CMDECOD",
+  "CMSTDT",
+  "DECODE",
   "DOMAIN",
   "END",
   "EVENTTYP",
@@ -48,7 +48,7 @@ utils::globalVariables(c(
   "LBDY",
   "LBSTNRHI",
   "LBSTNRLO",
-  "MHCAT", 
+  "MHCAT",
   "MHDECOD",
   "MHENDTC",
   "MHSTDTC",
@@ -57,8 +57,8 @@ utils::globalVariables(c(
   "PARAMCD",
   "START",
   "USUBJID",
-  "VISIT", 
-  "Visit", 
+  "VISIT",
+  "Visit",
   "all_of",
   "className",
   "col_exist",
@@ -74,7 +74,7 @@ utils::globalVariables(c(
   "hcl",
   "min_lbdt",
   "missing_disp",
-  "not_exist", 
+  "not_exist",
   "not_exist_disp",
   "ord",
   "setNames",
@@ -113,20 +113,73 @@ utils::globalVariables(c(
   "adtte",
   "warn",
   "dy_min",
-  "AEACN", "AEACNOTH", "AREL", "CNSR", "FASFL", "ITTFL", "LOWER", "Lower", 
-  "MEAN", "Mean (SD)",
-  "Median", "Min | Max", "N", "PANEL", "Q1 | Q3", "SAFFL", "SEM", "STD",
-  "TRTEMFL", "UPPER", "Upper",
-  "Variable", "ae_data", "avals_by", "bds_data", "colour", "colour2",
-  "corr", "corr_lab",
-  "corr_lab_hover", "descr", "grp", "id_block", "id_desc", "id_rn",
-  "id_stat", "inner_sort",
-  "lab", "n_subgroups", "n_tot", "orig_id_rn", "orig_var_rn", "param_x",
-  "param_y", "pt", "pval",
-  "pval_hover", "sort_n", "v", "var", "var_rn", "where", "y",
-  "type", "title"
-  ,":=",
-  "DATE", "EVENT_TIME", "DATE_ST", "DECODE_ST", "DATE_EN", "DECODE_EN"
+  "AEACN",
+  "AEACNOTH",
+  "AREL",
+  "CNSR",
+  "FASFL",
+  "ITTFL",
+  "LOWER",
+  "Lower",
+  "MEAN",
+  "Mean (SD)",
+  "Median",
+  "Min | Max",
+  "N",
+  "PANEL",
+  "Q1 | Q3",
+  "SAFFL",
+  "SEM",
+  "STD",
+  "TRTEMFL",
+  "UPPER",
+  "Upper",
+  "Variable",
+  "ae_data",
+  "avals_by",
+  "bds_data",
+  "colour",
+  "colour2",
+  "corr",
+  "corr_lab",
+  "corr_lab_hover",
+  "descr",
+  "grp",
+  "id_block",
+  "id_desc",
+  "id_rn",
+  "id_stat",
+  "inner_sort",
+  "lab",
+  "n_subgroups",
+  "n_tot",
+  "orig_id_rn",
+  "orig_var_rn",
+  "param_x",
+  "param_y",
+  "pt",
+  "pval",
+  "pval_hover",
+  "sort_n",
+  "v",
+  "var",
+  "var_rn",
+  "where",
+  "y",
+  "type",
+  "title",
+  ":=",
+  "DATE",
+  "EVENT_TIME",
+  "DATE_ST",
+  "DECODE_ST",
+  "DATE_EN",
+  "DECODE_EN",
+  "time",
+  "est_ci",
+  "Strata",
+  "0.95LCL",
+  "0.95UCL",
+  "label",
+  "id"
 ))
-
-
